// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

part 'quote_card_component.g.dart';

@ComponentProxyExtension()
abstract class QuoteCardComponent extends CardComponent
    with CopyWithMixin<$QuoteCardComponentCWProxy> {
  const QuoteCardComponent({
    this.avatar,
    this.name,
    this.subtitle,
    this.quote,
    this.leftQuote,
    this.rightQuote,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  /// Avatar of the contact who wrote the quote
  final Widget? avatar;

  /// Name of the contact who wrote the quote
  final TextWrapper? name;

  /// Subtitle, usually the date of the quote or the company of the contact
  final TextWrapper? subtitle;

  /// Quote
  final TextWrapper? quote;

  /// Left quote, usually a double quote
  final Widget? leftQuote;

  /// Right quote, usually a double quote
  final Widget? rightQuote;
}
