// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';
import 'package:wyatt_ui_kit_example/theme/constants.dart';

class PricingCards extends StatelessWidget {
  const PricingCards({super.key});

  @override
  Widget build(BuildContext context) => Column(
        children: [
          Text(
            'Pricing Cards',
            style: Theme.of(context).textTheme.titleMedium,
          ),
          const Gap(20),
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              PricingCard(
                title: const PricingLine(
                  data: TextWrapper('Lorem Ipsum'),
                  icon: Icon(
                    Icons.ac_unit_rounded,
                  ),
                ),
                pricing: const Pricing(
                  price: TextWrapper('450€'),
                  period: TextWrapper('/ jour'),
                  hasAsterisk: true,
                ),
                description: const TextWrapper(
                    'Cupidatat reprehenderit aliqua eiusmod Lorem. '
                    'Qui ipsum id ea ea nulla labore aute ullamco aute '
                    'quis elit ut amet velit. Incididunt fugiat proident '
                    'proident deserunt tempor Lorem cillum qui do '
                    'ullamco Lorem magna ipsum. Ullamco cupidatat velit '),
                features: const [
                  PricingLine(
                    icon: Icon(
                      Icons.ac_unit_rounded,
                    ),
                    data: TextWrapper(
                      'Nulla labore aliquip dolor aliqua elit anim quis '
                      'non officia laboris ad.',
                    ),
                  ),
                  PricingLine(
                    icon: Icon(
                      Icons.ac_unit_rounded,
                    ),
                    data: TextWrapper(
                      'Eu pariatur non et sint minim aute pariatur '
                      'amet officia.',
                    ),
                  ),
                ],
                cta: context.components.flatButtonComponent.call(
                  label: const TextWrapper(
                    'Contactez-nous',
                    style: TextStyle(color: Colors.white),
                  ),
                  normalStyle: FlatButtonThemeExtensionImpl.dark(
                    theme: Theme.of(context),
                  ).normalStyle?.copyWith(
                        backgroundColors:
                            const MultiColor(Constants.blueBtnGradient),
                        borderColors:
                            const MultiColor(Constants.blueBtnGradient),
                      ),
                ),
              ),
              const Gap(20),
              PricingCard(
                title: const PricingLine(
                  data: TextWrapper('Lorem Ipsum'),
                  icon: Icon(
                    Icons.ac_unit_rounded,
                  ),
                ),
                pricing: const Pricing(
                  price: TextWrapper('350€'),
                  period: TextWrapper('/ jour'),
                  hasAsterisk: true,
                ),
                features: const [
                  PricingLine(
                    icon: Icon(
                      Icons.ac_unit_rounded,
                    ),
                    data: TextWrapper(
                      'Nulla labore aliquip dolor aliqua elit anim quis '
                      'non officia laboris ad.',
                    ),
                  ),
                  PricingLine(
                    icon: Icon(
                      Icons.ac_unit_rounded,
                    ),
                    data: TextWrapper(
                      'Eu pariatur non et sint minim aute pariatur '
                      'amet officia.',
                    ),
                  ),
                  PricingLine(
                    icon: Icon(
                      Icons.ac_unit_rounded,
                    ),
                    data: TextWrapper(
                      'Nulla labore aliquip dolor aliqua elit anim '
                      'quis non officia laboris ad.',
                    ),
                  ),
                ],
                cta: context.components.flatButtonComponent.call(
                  label: const TextWrapper(
                    'Contactez-nous',
                    style: TextStyle(color: Colors.white),
                  ),
                  normalStyle: FlatButtonThemeExtensionImpl.dark(
                    theme: Theme.of(context),
                  ).normalStyle?.copyWith(
                        backgroundColors:
                            const MultiColor(Constants.purpleGradient),
                        borderColors:
                            const MultiColor(Constants.purpleGradient),
                      ),
                ),
              ),
            ],
          ),
          const Gap(20),
        ],
      );
}
