// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/core/design_system/colors.dart';

class SimpleIconButtonThemeExtensionImpl
    extends SimpleIconButtonThemeExtension {
  const SimpleIconButtonThemeExtensionImpl({
    super.disabledStyle,
    super.focusedStyle,
    super.hoveredStyle,
    super.normalStyle,
    super.tappedStyle,
  });

  factory SimpleIconButtonThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    final style = SimpleIconButtonStyle(
      dimension: 30,
      radius: BorderRadius.circular(5),
      padding: const EdgeInsets.all(5),
      foregroundColors: const MultiColor.single(WyattColors.gray2),
      backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.2)),
      animationDuration: const Duration(milliseconds: 150),
    );

    return SimpleIconButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        foregroundColors: MultiColor.single(WyattColors.gray2.withOpacity(0.4)),
      ),
      hoveredStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      focusedStyle: style,
      tappedStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.5)),
      ),
    );
  }

  factory SimpleIconButtonThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    final style = SimpleIconButtonStyle(
      dimension: 30,
      radius: const BorderRadius.all(Radius.circular(5)),
      padding: const EdgeInsets.all(5),
      foregroundColors: const MultiColor.single(WyattColors.light),
      backgroundColors: MultiColor.single(WyattColors.light.withOpacity(0.04)),
      animationDuration: const Duration(milliseconds: 150),
    );
    return SimpleIconButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        foregroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      hoveredStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      focusedStyle: style,
      tappedStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.5)),
      ),
    );
  }
}
