// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/core/design_system/colors.dart';

class SymbolButtonThemeExtensionImpl extends SymbolButtonThemeExtension {
  const SymbolButtonThemeExtensionImpl({
    super.disabledStyle,
    super.focusedStyle,
    super.hoveredStyle,
    super.normalStyle,
    super.tappedStyle,
    super.selectedStyle,
  });

  factory SymbolButtonThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    final style = SymbolButtonStyle(
      labelStyle: theme.textTheme.labelLarge,
      dimension: 60,
      radius: BorderRadius.circular(12),
      padding: const EdgeInsets.all(10),
      foregroundColors: const MultiColor.single(WyattColors.gray2),
      backgroundColors: MultiColor.single(WyattColors.light.withOpacity(0.04)),
      borderColors: const MultiColor.single(WyattColors.gray2),
      stroke: 2,
      animationDuration: const Duration(milliseconds: 150),
    );
    return SymbolButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: WyattColors.gray1,
        ),
        foregroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
        backgroundColors: const MultiColor.single(WyattColors.light),
        borderColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      hoveredStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      focusedStyle: style.copyWith(stroke: 4),
      tappedStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.gray1.withOpacity(0.4)),
      ),
      selectedStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          fontWeight: FontWeight.w600,
        ),
        foregroundColors: const MultiColor.single(WyattColors.gray2),
        borderColors: WyattColors.greenGradient,
      ),
    );
  }

  factory SymbolButtonThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    final style = SymbolButtonStyle(
      labelStyle: theme.textTheme.labelLarge,
      dimension: 60,
      radius: const BorderRadius.all(Radius.circular(12)),
      padding: const EdgeInsets.all(10),
      foregroundColors: const MultiColor.single(WyattColors.light),
      backgroundColors: MultiColor.single(WyattColors.light.withOpacity(0.04)),
      borderColors: const MultiColor.single(WyattColors.gray1),
      stroke: 2,
      animationDuration: const Duration(milliseconds: 150),
    );
    return SymbolButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: WyattColors.gray1,
        ),
        foregroundColors: const MultiColor.single(WyattColors.gray1),
        backgroundColors:
            MultiColor.single(WyattColors.gray1.withOpacity(0.04)),
      ),
      hoveredStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(WyattColors.gray1.withOpacity(0.04)),
      ),
      focusedStyle: style.copyWith(stroke: 4),
      tappedStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(WyattColors.gray1.withOpacity(0.04)),
      ),
      selectedStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          fontSize: 14,
          fontWeight: FontWeight.w600,
        ),
        foregroundColors: const MultiColor.single(WyattColors.light),
        borderColors: WyattColors.greenGradient,
      ),
    );
  }
}
